from setuptools import setup

setup(name='gb_distributions_probab',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['gb_distributions_probab'],
      zip_safe=False)
